<?php

/**
 * The admin-specific functionality of the plugin.
 *
 * @link       https://hashtechy.com
 * @since      1.0.0
 *
 * @package    Easy_Custom_Post_Type_Ui
 * @subpackage Easy_Custom_Post_Type_Ui/admin
 */

/**
 * The admin-specific functionality of the plugin.
 *
 * Defines the plugin name, version, and two examples hooks for how to
 * enqueue the admin-specific stylesheet and JavaScript.
 *
 * @package    Easy_Custom_Post_Type_Ui
 * @subpackage Easy_Custom_Post_Type_Ui/admin
 * @author     Hashtechy <tech@hashtechy.com>
 */

require_once plugin_dir_path( dirname( __FILE__ ) ) . 'admin/partials/easy-custom-post-type-ui-admin-display.php';
class Easy_Custom_Post_Type_Ui_Admin extends admin_area_view {

	/**
	 * The ID of this plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 * @var      string    $plugin_name    The ID of this plugin.
	 */
	private $plugin_name;

	/**
	 * The version of this plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 * @var      string    $version    The current version of this plugin.
	 */
	private $version;

	/**
	 * Initialize the class and set its properties.
	 *
	 * @since    1.0.0
	 * @param      string    $plugin_name       The name of this plugin.
	 * @param      string    $version    The version of this plugin.
	 */
	public function __construct( $plugin_name, $version ) {

		$this->plugin_name = $plugin_name;
		$this->version = $version;
		
		add_action( 'init', [$this, 'register_custom_taxonomies'] );	
		add_action( 'init', [$this, 'cpt_register_custom_post_type'] );
		
	}

	/**
	 * Register the stylesheets for the admin area.
	 *
	 * @since    1.0.0
	 */
	public function enqueue_styles() {
		
		$page = ( isset( $_GET['page'] ) 	&& sanitize_text_field( $_GET['page'] ) === 'c-p-t' ? 				sanitize_text_field( $_GET['page'] ) : '' );
		$pages = ( isset( $_GET['page'] ) 	&& sanitize_text_field( $_GET['page'] ) === 'c-p-t-taxonomies' ? 	sanitize_text_field( $_GET['page'] ) : '' );
		
		if( !empty( $page ) || !empty( $pages ) ) {
			wp_enqueue_style( $this->plugin_name, 		plugin_dir_url( __FILE__ ) . 'css/easy-custom-post-type-ui-admin.css', 	array(), 				$this->version, 'all' );
			wp_enqueue_style( 'dashicons-picker', 		plugin_dir_url( __FILE__ ) . 'css/dashicons-picker.css', 				array( 'dashicons' ), 	$this->version, 'all' );
			wp_enqueue_style( 'all-css', 				plugin_dir_url( __FILE__ ) . 'css/all.css', 							array(), 				$this->version, 'all' );
			wp_enqueue_style( 'webpixels-css', 			plugin_dir_url( __FILE__ ) . 'css/webpixels.css', array(), $this->version, 'all' );
			wp_enqueue_style( 'bootstrapss-icons-min',	'https://cdnjs.cloudflare.com/ajax/libs/bootstrap-icons/1.4.0/font/bootstrap-icons.min.css' );
		}
	}

	/**
	 * Register the JavaScript for the admin area.
	 *
	 * @since    1.0.0
	 */
	public function enqueue_scripts() {
		
		$page = ( isset( $_GET['page'] ) 	&& sanitize_text_field( $_GET['page'] ) === 'c-p-t' ? 				sanitize_text_field( $_GET['page'] ) : '' );
		$pages = ( isset( $_GET['page'] ) 	&& sanitize_text_field( $_GET['page'] ) === 'c-p-t-taxonomies' ? 	sanitize_text_field( $_GET['page'] ) : '' );
		
		if( !empty( $page ) || !empty( $pages ) ) {

			wp_enqueue_script( $this->plugin_name, 	plugin_dir_url( __FILE__ ) . 'js/easy-custom-post-type-ui-admin.js', 	array( 'jquery' ), 	$this->version, false );
			wp_enqueue_script( 'dashicons-picker', 	plugin_dir_url( __FILE__ ) . 'js/dashicons-picker.js', 					array( 'jquery' ), 	$this->version, false );			
		}
	}


	public function cpt_admin_menus() {
		add_menu_page(
			__( 'CPT', 'easy-author-avatar-image' ),
			__( 'CPT', 'easy-author-avatar-image' ),
			'manage_options',
			'c-p-t',
			array( $this, 'cpt_page_callback' ),
			'dashicons-nametag'
		);

		add_submenu_page( 
			'c-p-t', 
			__( 'Taxonomies', 'easy-author-avatar-image' ),
			__( 'Taxonomies', 'easy-author-avatar-image' ),
			'manage_options',
			'c-p-t-taxonomies',
			array( $this, 'taxonomies_page_callback' ),
		);
	}

	public function cpt_register_custom_post_type() {

		$post_type = get_option( 'cpt' );

		if( !empty( $post_type ) ) {
			foreach( $post_type as $post => $post_data ) {			
				$name 					= ( isset( $post_data['_post_label'] ) 				? sanitize_text_field( $post_data['_post_label'] ) 		 	: '' );
				$singular_label 		= ( isset( $post_data['_post_singular_label'] ) 	? sanitize_text_field( $post_data['_post_singular_label'] ) 	: '' );
				$menu_name 				= ( isset( $post_data['_menu_name'] ) 				? sanitize_text_field( $post_data['_menu_name'] ) 				: '' );
				$name_admin_bar 		= ( isset( $post_data['_name_admin_bar'] ) 			? sanitize_text_field( $post_data['_name_admin_bar'] ) 		: '' );
				$new_item 				= ( isset( $post_data['_new_item'] ) 				? sanitize_text_field( $post_data['_new_item'] ) 				: '' );
				$edit_item 				= ( isset( $post_data['_edit_item'] ) 				? sanitize_text_field( $post_data['_edit_item'] )				: '' );
				$view_item 				= ( isset( $post_data['_view_item'] ) 				? sanitize_text_field( $post_data['_view_item'] ) 				: '' );
				$all_items 				= ( isset( $post_data['_all_items'] ) 				? sanitize_text_field( $post_data['_all_items'] ) 				: '' );
				$search_items 			= ( isset( $post_data['_search_items'] )			? sanitize_text_field( $post_data['_search_items'] )			: '' );
				$parent_item_colon		= ( isset( $post_data['_parent_item_colon'] )		? sanitize_text_field( $post_data['_parent_item_colon'] )		: '' );
				$not_found 				= ( isset( $post_data['_not_found'] ) 				? sanitize_text_field( $post_data['_not_found'] )				: '' );
				$not_found_in_trash		= ( isset( $post_data['_not_found_in_trash'] ) 		? sanitize_text_field( $post_data['_not_found_in_trash'] )		: '' );
				$featured_image 		= ( isset( $post_data['_featured_image'] ) 			? sanitize_text_field( $post_data['_featured_image'] )			: '' );
				
				
				$archives 				= ( isset( $post_data['_archives'] ) 				? sanitize_text_field( $post_data['_archives'] )				: '' );
				$insert_into_item 		= ( isset( $post_data['_insert_into_item'] ) 		? sanitize_text_field( $post_data['_insert_into_item'] )		: '' );
				$uploaded_to_this_item	= ( isset( $post_data['_uploaded_to_this_item'] )	? sanitize_text_field( $post_data['_uploaded_to_this_item'] )	: '' );
				$filter_items_list 		= ( isset( $post_data['_filter_items_list'] ) 		? sanitize_text_field( $post_data['_filter_items_list'] )		: '' );
				$items_list_navigation	= ( isset( $post_data['_items_list_navigation'] )	? sanitize_text_field( $post_data['_items_list_navigation'] )	: '' );
				$items_list 			= ( isset( $post_data['_items_list'] ) 				? sanitize_text_field( $post_data['_items_list'] )				: '' );
				$show_in_menu 			= ( isset( $post_data['_show_in_menu'] ) 			? sanitize_text_field( $post_data['_show_in_menu'] )			: '' );
				$query_var 				= ( isset( $post_data['_query_var'] ) 				? sanitize_text_field( $post_data['_query_var'] )				: '' );
				$rewrite 				= ( isset( $post_data['_rewrite'] ) 				? sanitize_text_field( $post_data['_rewrite'] )				: '' );
				$menu_position 			= ( isset( $post_data['_menu_position'] ) 			? sanitize_text_field( $post_data['_menu_position'] )			: '' );
				$dash_icons 			= ( isset( $post_data['_dash_icons'] ) 				? sanitize_text_field( $post_data['_dash_icons'] )				: '' );
				
				$supports_title = $supports_editor = $supports_author =  $supports_thumbnail = $supports_excerpt = $supports_comments = '';

				if( isset( $post_data['_post_supports_title'] ) && sanitize_text_field( $post_data['_post_supports_title'] ) !== '' ) {
					$supports_title = 'title';
				}

				if( isset( $post_data['_post_supports_editor'] ) && sanitize_text_field( $post_data['_post_supports_editor'] ) !== '' ) {
					$supports_editor = 'editor';
				}

				if( isset( $post_data['_post_supports_author'] ) && sanitize_text_field( $post_data['_post_supports_author'] ) !== '' ) {
					$supports_author = 'author';
				}

				if( isset( $post_data['_post_supports_thumbnail'] ) && sanitize_text_field( $post_data['_post_supports_thumbnail'] ) !== '' ) {
					$supports_thumbnail = 'thumbnail';
				}

				if( isset( $post_data['_post_supports_excerpt'] ) && sanitize_text_field( $post_data['_post_supports_excerpt'] ) !== '' ) {
					$supports_excerpt = 'excerpt';
				}

				if( isset( $post_data['_post_supports_comments'] ) && sanitize_text_field( $post_data['_post_supports_comments'] ) !== '' ) {
					$supports_comments = 'comments';
				}
			
				$labels = array(
					'name'					=> __( $name, 'Post type general name', 'textdomain' ),
					'singular_name'			=> __( $singular_label, 'Post type singular name', 'textdomain' ),
					'menu_name'				=> __( $menu_name, 'Admin Menu text', 'textdomain' ),
					'name_admin_bar'		=> __( $name_admin_bar, 'Add New on Toolbar', 'textdomain' ),
					'add_new'				=> __( 'Add New', 'textdomain' ),
					'add_new_item'			=> __( 'Add New '.$name.'', 'textdomain' ),
					'new_item'				=> __( 'New '.$new_item.' ', 'textdomain' ),
					'edit_item'				=> __( 'Edit '.$edit_item.' ', 'textdomain' ),
					'view_item'				=> __( 'View '.$view_item.' ', 'textdomain' ),
					'all_items'				=> __( 'All '.$all_items.' ', 'textdomain' ),
					'search_items'			=> __( 'Search '.$search_items.' ', 'textdomain' ),
					'parent_item_colon'		=> __( 'Parent '.$parent_item_colon.':', 'textdomain' ),
					'not_found'				=> __( 'No '.$not_found.' found.', 'textdomain' ),
					'not_found_in_trash'	=> __( 'No '.$not_found_in_trash.' found in Trash.', 'textdomain' ),
					'featured_image'		=> __( ''.$featured_image.' Cover Image', 'Overrides the “Featured Image” phrase for this post type. Added in 4.3', 'textdomain' ),
					'set_featured_image'	=> __( 'Set cover image', 'Overrides the “Set featured image” phrase for this post type. Added in 4.3', 'textdomain' ),
					'remove_featured_image' => __( 'Remove cover image', 'Overrides the “Remove featured image” phrase for this post type. Added in 4.3', 'textdomain' ),
					'use_featured_image'    => __( 'Use as cover image', 'Overrides the “Use as featured image” phrase for this post type. Added in 4.3', 'textdomain' ),
					'archives'				=> __( ' '.$archives.' archives', 'The post type archive label used in nav menus. Default “Post Archives”. Added in 4.4', 'textdomain' ),
					'insert_into_item'		=> __( 'Insert into  '.$insert_into_item.' ', 'Overrides the “Insert into post”/”Insert into page” phrase (used when inserting media into a post). Added in 4.4', 'textdomain' ),
					'uploaded_to_this_item' => __( 'Uploaded to this '.$uploaded_to_this_item.' ', 'Overrides the “Uploaded to this post”/”Uploaded to this page” phrase (used when viewing media attached to a post). Added in 4.4', 'textdomain' ),
					'filter_items_list'		=> __( 'Filter '.$filter_items_list.' list', 'Screen reader text for the filter links heading on the post type listing screen. Default “Filter posts list”/”Filter pages list”. Added in 4.4', 'textdomain' ),
					'items_list_navigation' => __( ' '.$items_list_navigation.' list navigation', 'Screen reader text for the pagination heading on the post type listing screen. Default “Posts list navigation”/”Pages list navigation”. Added in 4.4', 'textdomain' ),
					'items_list'			=> __( ' '.$items_list.' list', 'Screen reader text for the items list heading on the post type listing screen. Default “Posts list”/”Pages list”. Added in 4.4', 'textdomain' ),
				);
			
				$args = array(
					'labels'        	  => $labels,
					'description'   	  => 'Holds our Annual Conference and Annual Conference specific data',					
					'supports'			  => array( $supports_title, $supports_editor, $supports_author, $supports_thumbnail, $supports_excerpt, $supports_comments ),
					'has_archive'   	  => true,
					'hierarchical'        => false,
					'public'              => true,
					'show_ui'             => true,
					'show_in_menu'        => true,
					'show_in_nav_menus'   => true,
					'show_in_admin_bar'   => true,		
					'can_export'          => true,
					'exclude_from_search' => false,
					'publicly_queryable'  => true,
					'capability_type'     => 'post',
					'show_in_rest'        => true,	
					'menu_icon'			  => $dash_icons,								
				);	
				register_post_type( $post, $args );
			}
		}
	
	}

	public function register_custom_taxonomies() {

		$c_p_t_taxonomy = get_option( 'c_p_t_taxonomy' );
		if( !empty( $c_p_t_taxonomy ) ) {
			foreach ( $c_p_t_taxonomy as $key => $taxonomy ) {
				
				$post_type 			= ( isset( $taxonomy['post_type'] ) 		? sanitize_text_field( $taxonomy['post_type'] ) 			: '' );
				$name 				= ( isset( $taxonomy['name'] ) 				? sanitize_text_field( $taxonomy['name'] ) 				: '' );
				$singular_name 		= ( isset( $taxonomy['singular_name'] ) 	? sanitize_text_field( $taxonomy['singular_name'] ) 		: '' );
				$search_items 		= ( isset( $taxonomy['search_items'] ) 		? sanitize_text_field( $taxonomy['search_items'] ) 		: '' );
				$all_items 			= ( isset( $taxonomy['all_items'] ) 		? sanitize_text_field( $taxonomy['all_items'] ) 			: '' );
				$parent_item 		= ( isset( $taxonomy['parent_item'] ) 		? sanitize_text_field( $taxonomy['parent_item'] ) 			: '' );
				$parent_item_colon 	= ( isset( $taxonomy['parent_item_colon'] ) ? sanitize_text_field( $taxonomy['parent_item_colon'] ) 	: '' );
				$edit_item 			= ( isset( $taxonomy['edit_item'] ) 		? sanitize_text_field( $taxonomy['edit_item'] ) 			: '' );
				$update_item	 	= ( isset( $taxonomy['update_item'] ) 		? sanitize_text_field( $taxonomy['update_item'] ) 			: '' );
				$add_new_item 		= ( isset( $taxonomy['add_new_item'] ) 		? sanitize_text_field( $taxonomy['add_new_item'] ) 		: '' );
				$new_item_name 		= ( isset( $taxonomy['new_item_name'] ) 	? sanitize_text_field( $taxonomy['new_item_name'] ) 		: '' );
				$menu_name 			= ( isset( $taxonomy['menu_name'] ) 		? sanitize_text_field( $taxonomy['menu_name'] ) 			: '' );


				$labels = [
					"name" => esc_html__( $name, "twentytwentythree" ),
					"singular_name" => esc_html__( $key, "twentytwentythree" ),
				];
			
				
				$args = [
					"label" => esc_html__( $key, "twentytwentythree" ),
					"labels" => $labels,
					"public" => true,
					"publicly_queryable" => true,
					"hierarchical" => true,
					"show_ui" => true,
					"show_in_menu" => true,
					"show_in_nav_menus" => true,
					"query_var" => true,
					"rewrite" => [ 'slug' => $key, 'with_front' => false, ],
					"show_admin_column" => true,
					"show_in_rest" => true,
					"show_tagcloud" => true,
					"rest_base" => $key,
					"rest_controller_class" => "WP_REST_Terms_Controller",
					"rest_namespace" => "wp/v2",
					"show_in_quick_edit" => false,
					"sort" => true,
					"show_in_graphql" => true,
					'orderby'      => 'parent',
					'id'           => 'categories_dropdown',
					'value_field'  => 'slug',
				];
				register_taxonomy( $key, [ $post_type ], $args );
			}
		}
	}
}
