<?php 
    $cpt = get_option( 'cpt' ); 
    require_once 'post-type-update.php';
?>
<!-- Main content -->
<div class="h-screen flex-grow-1 overflow-y-lg-auto">
    <!-- Header -->
    <header class="bg-surface-primary border-bottom pt-6">
        <div class="container-fluid">
            <div class="mb-npx">
                <div class="row align-items-center">
                    <div class="col-sm-6 col-12 mb-4 mb-sm-0">
                        <!-- Title -->
                        <h1 class="h2 mb-0 ls-tight"><?php _e( 'Post Type', 'easy-custom-post-type-ui' ); ?></h1>
                    </div>
                </div>

                <!-- Nav -->
                <ul class="nav nav-tabs mt-4 overflow-x border-0">
                    <li class="nav-item <?php echo esc_attr( $first_tab_active ); ?>">
                        <a href="<?php echo esc_url( admin_url( 'admin.php?page=c-p-t' ) ); ?>" class="nav-link <?php echo esc_attr( $first_tab_active ); ?>">
                            <?php _e( 'All Post', 'easy-custom-post-type-ui' ); ?>
                        </a>
                    </li>

                    <li class="nav-item">
                        <a href="<?php echo esc_url( admin_url( 'admin.php?page=c-p-t&tab=add-post' ) ); ?>" class="nav-link <?php echo ( 'add-post' === $current_tab ) ? 'active' : '';  ?>">
                            <?php _e( 'Add Post', 'easy-custom-post-type-ui' ); ?>
                        </a>
                    </li>

                    <li class="nav-item">
                        <a href="<?php echo esc_url( admin_url( 'admin.php?page=c-p-t&tab=update-post' ) ); ?>" class="nav-link <?php echo ( 'update-post' === $current_tab ) ? 'active' : '';  echo ( 'update-post' === $current_tab ) ? '' : 'hidden'; ?>">
                            <?php _e( 'Edit Post', 'easy-custom-post-type-ui' ); ?>
                        </a>
                    </li>
                </ul>
            </div>
        </div>
    </header>
    <!-- Main -->
    <main class="py-6 bg-surface-secondary ">
        <div class="container-fluid">
            <div class="<?php echo ($first_tab_active) ? '' : 'hidden'; ?>">
                <!-- Card stats -->
                <div class="row g-6 mb-6">
                    <div class="col-xl-3 col-sm-6 col-12">
                        <div class="card shadow border-0">
                            <div class="card-body">
                                <div class="row">
                                    <div class="col">
                                        <span class="h6 font-semibold text-muted text-sm d-block mb-2"><?php _e( 'Total Post',  'easy-custom-post-type-ui' ); ?></span>
                                        <span class="h3 font-bold mb-0"><?php echo isset( $cpt ) && !empty( $cpt ) ? count( $cpt ) : ''; ?></span>
                                    </div>
                                    <div class="col-auto">
                                        <div class="icon icon-shape bg-primary text-white text-lg rounded-circle">
                                            <i class="bi bi-people"></i>
                                        </div>
                                    </div>
                                </div>
                            </div>
                        </div>
                    </div>
                </div>
                <!--- Table Start --->
                <div class="card shadow border-0 mb-7 ">
                    <div class="card-header">
                        <h5 class="mb-0"><?php _e( 'Add Edit Post Types', 'easy-custom-post-type-ui' ); ?></h5>
                    </div>
                    <div class="table-responsive">
                        <table class="table table-hover table-nowrap">
                            <thead class="thead-light">
                                <tr>
                                    <th scope="col"><?php _e( 'Post Slug',  'easy-custom-post-type-ui' ); ?></th>
                                    <th scope="col"><?php _e( 'Post Label', 'easy-custom-post-type-ui' ); ?></th>
                                    <th scope="col"><?php _e( 'Post Singular Label', 'easy-custom-post-type-ui' ); ?></th>
                                    <th scope="col"><?php _e( 'Action', 'easy-custom-post-type-ui' ); ?></th>
                                </tr>
                            </thead>
                            <tbody>
                                <?php
                                    if( !empty( $cpt ) ) {
                                        foreach ($cpt as $key => $post) { ?>
                                            <tr>
                                                <td>
                                                    <p><?php echo esc_attr( $key ); ?></p>
                                                </td>
                                                <td>
                                                    <p><?php echo esc_attr( $post['_post_label'] ) ?></p>
                                                </td>
                                                <td>
                                                    <p><?php echo esc_attr($post['_post_singular_label']) ?></p>
                                                </td>
                                                <td>
                                                    <a href="<?php echo esc_url( admin_url( 'admin.php?page=c-p-t&tab=update-post&post-type=' .  $key . '' ) ); ?>" class="btn btn-sm btn-neutral"><?php _e( 'Edit',  'easy-custom-post-type-ui' ); ?></a>
                                                    <a href="<?php echo esc_url( admin_url( 'admin.php?page=c-p-t&delete=' . $key . '' ) ); ?>" type="button" class="btn btn-sm btn-square btn-neutral text-danger-hover">
                                                        <i class="bi bi-trash"></i>
                                                    </a>
                                                </td>
                                            </tr>
                                            <?php 
                                        }
                                    }
                                ?>
                            </tbody>
                        </table>
                    </div>
                </div>
            </div>

            <div class="<?php echo ( $first_tab_active ) ? 'hidden' : ''; ?>">

                <section class="post-section">
                    <div class="l-inner">
                        <!-- Main Settings Start -->
                        <details class="post-section-item">
                            <summary class="post-section-question"><?php _e( 'Main Settings', 'easy-custom-post-type-ui' ); ?><span class="post-section-icon"></span></summary>
                            <div class="post-section-answer">
                                <div class="post-section-answer-inner">

                                    <div class="post-input-group <?php echo ( 'update-post' === $current_tab ) ? 'hidden' : ''; ?>">
                                        <input type="text" name="_post_slug" value="<?php echo ( isset( $post_slug ) ? esc_html( $post_slug ) : '' ); ?>" required>
                                        <span class="highlight"></span>
                                        <span class="bar"></span>
                                        <label><?php _e( 'Post Slug', 'easy-custom-post-type-ui' ); ?></label>
                                        <p><?php _e( 'The Post Type Name Slug. Used For Various Queries For Post Type Content.', 'easy-custom-post-type-ui' ); ?></p>
                                    </div>

                                    <div class="post-input-group">
                                        <input type="text" name="_post_label" value="<?php echo ( isset( $post_name ) ? esc_html( $post_name ) : '' ); ?>" required>
                                        <span class="highlight"></span>
                                        <span class="bar"></span>
                                        <label><?php _e( 'Post Name', 'easy-custom-post-type-ui' ); ?></label>
                                        <p><?php _e( 'Used For The Post Type Admin Menu Item.', 'easy-custom-post-type-ui' ); ?></p>
                                    </div>

                                    <div class="post-input-group">
                                        <input type="text" name="_post_singular_label" value="<?php echo ( isset( $singular_label ) ? esc_html( $singular_label ) : '' ); ?>"" required>
                                        <span class="highlight"></span>
                                        <span class="bar"></span>
                                        <label><?php _e( 'Post Singular Name', 'easy-custom-post-type-ui' ); ?></label>
                                        <p><?php _e( 'Used When A Singular Label Is Needed.', 'easy-custom-post-type-ui' ); ?></p>
                                    </div>
                                </div>
                            </div>
                        </details>
                        <!-- Main Settings End -->

                        <!-- Main Labels Start -->
                        <details class="post-section-item">
                            <summary class="post-section-question"><?php _e( 'Labels Settings', 'easy-custom-post-type-ui' ); ?><span class="post-section-icon"></span></summary>
                            <div class="post-section-answer">
                                <div class="post-section-answer-inner">

                                    <div class="post-input-group">
                                        <input type="text" name="_menu_name" value="<?php echo ( isset( $menu_name ) ? esc_html( $menu_name ) : '' ); ?>" required>
                                        <span class="highlight"></span>
                                        <span class="bar"></span>
                                        <label><?php _e( 'Menu Name', 'easy-custom-post-type-ui' ); ?></label>
                                        <p><?php _e( 'Admin Menu Name For Your Custom Post Type.', 'easy-custom-post-type-ui' ); ?></p>
                                    </div>

                                    <div class="post-input-group">
                                        <input type="text" name="_name_admin_bar" value="<?php echo ( isset( $name_admin_bar ) ? esc_html( $name_admin_bar ) : '' ); ?>" required>
                                        <span class="highlight"></span>
                                        <span class="bar"></span>
                                        <label><?php _e( 'Admin Bar Name', 'easy-custom-post-type-ui' ); ?></label>
                                        <p><?php _e( 'Admin Bar Name For Your Custom Post Type.', 'easy-custom-post-type-ui' ); ?></p>
                                    </div>

                                    <div class="post-input-group">
                                        <input type="text" name="_new_item" value="<?php echo ( isset( $new_item ) ? esc_html( $new_item ) : '' ); ?>" required>
                                        <span class="highlight"></span>
                                        <span class="bar"></span>
                                        <label><?php _e( 'New Item', 'easy-custom-post-type-ui' ); ?></label>
                                        <p><?php _e( 'New Item Label For Your Custom Post Type.', 'easy-custom-post-type-ui' ); ?></p>
                                    </div>

                                    <div class="post-input-group">
                                        <input type="text" name="_edit_item" value="<?php echo ( isset( $edit_item ) ? esc_html( $edit_item ) : '' ); ?>" required>
                                        <span class="highlight"></span>
                                        <span class="bar"></span>
                                        <label><?php _e( 'Edit Item', 'easy-custom-post-type-ui' ); ?></label>
                                        <p><?php _e( 'Edit Item Label For Your Custom Post Type.', 'easy-custom-post-type-ui' ); ?></p>
                                    </div>

                                    <div class="post-input-group">
                                        <input type="text" name="_view_item" value="<?php echo ( isset( $view_item ) ? esc_html( $view_item ) : '' ); ?>" required>
                                        <span class="highlight"></span>
                                        <span class="bar"></span>
                                        <label><?php _e( 'View Item', 'easy-custom-post-type-ui' ); ?></label>
                                        <p><?php _e( 'View Item Label For Your Custom Post Type.', 'easy-custom-post-type-ui' ); ?></p>
                                    </div>

                                    <div class="post-input-group">
                                        <input type="text" name="_all_items" value="<?php echo ( isset( $all_items ) ? esc_html( $all_items ) : '' ); ?>" required>
                                        <span class="highlight"></span>
                                        <span class="bar"></span>
                                        <label><?php _e( 'All Item', 'easy-custom-post-type-ui' ); ?></label>
                                        <p><?php _e( 'All Item Label For Your Custom Post Type.', 'easy-custom-post-type-ui' ); ?></p>
                                    </div>

                                    <div class="post-input-group">
                                        <input type="text" name="_search_items" value="<?php echo ( isset( $search_items ) ? esc_html( $search_items ) : '' ); ?>" required>
                                        <span class="highlight"></span>
                                        <span class="bar"></span>
                                        <label><?php _e( 'Search Items', 'easy-custom-post-type-ui' ); ?></label>
                                        <p><?php _e( 'Search Item Label For Your Custom Post Type.', 'easy-custom-post-type-ui' ); ?></p>
                                    </div>

                                    <div class="post-input-group">
                                        <input type="text" name="_parent_item_colon" value="<?php echo ( isset( $parent_item_colon ) ? esc_html( $parent_item_colon ) : '' ); ?>" required>
                                        <span class="highlight"></span>
                                        <span class="bar"></span>
                                        <label><?php _e( 'Parent Item Colon', 'easy-custom-post-type-ui' ); ?></label>
                                        <p><?php _e( 'Parent Item Colon Label For Your Custom Post Type.', 'easy-custom-post-type-ui' ); ?></p>
                                    </div>

                                    <div class="post-input-group">
                                        <input type="text" name="_not_found" value="<?php echo ( isset( $not_found ) ? esc_html( $not_found ) : '' ); ?>" required>
                                        <span class="highlight"></span>
                                        <span class="bar"></span>
                                        <label><?php _e( 'Not Found', 'easy-custom-post-type-ui' ); ?></label>
                                        <p><?php _e( 'Not Found Label For Your Custom Post Type.', 'easy-custom-post-type-ui' ); ?></p>
                                    </div>

                                    <div class="post-input-group">
                                        <input type="text" name="_not_found_in_trash" value="<?php echo ( isset( $not_found_in_trash ) ? esc_html( $not_found_in_trash ) : '' ); ?>" required>
                                        <span class="highlight"></span>
                                        <span class="bar"></span>
                                        <label><?php _e( 'Not Found In Trash', 'easy-custom-post-type-ui' ); ?></label>
                                        <p><?php _e( 'Not Found In Trash Label For Your Custom Post Type.', 'easy-custom-post-type-ui' ); ?></p>
                                    </div>

                                    <div class="post-input-group">
                                        <input type="text" name="_featured_image" value="<?php echo ( isset( $featured_image ) ? esc_html( $featured_image ) : '' ); ?>" required>
                                        <span class="highlight"></span>
                                        <span class="bar"></span>
                                        <label><?php _e( 'Featured Image', 'easy-custom-post-type-ui' ); ?></label>
                                        <p><?php _e( 'Featured Image Label For Your Custom Post Type.', 'easy-custom-post-type-ui' ); ?></p>
                                    </div>

                                    <div class="post-input-group">
                                        <input type="text" name="_archives" value="<?php echo ( isset( $archives ) ? esc_html( $archives ) : '' ); ?>" required>
                                        <span class="highlight"></span>
                                        <span class="bar"></span>
                                        <label><?php _e( 'Archives', 'easy-custom-post-type-ui' ); ?></label>
                                        <p><?php _e( 'Archives Label For Your Custom Post Type.', 'easy-custom-post-type-ui' ); ?></p>
                                    </div>

                                    <div class="post-input-group">
                                        <input type="text" name="_insert_into_item" value="<?php echo ( isset( $insert_into_item ) ? esc_html( $insert_into_item ) : '' ); ?>" required>
                                        <span class="highlight"></span>
                                        <span class="bar"></span>
                                        <label><?php _e( 'insert Into Item', 'easy-custom-post-type-ui' ); ?></label>
                                        <p><?php _e( 'insert Into Item Label For Your Custom Post Type.', 'easy-custom-post-type-ui' ); ?></p>
                                    </div>

                                    <div class="post-input-group">
                                        <input type="text" name="_uploaded_to_this_item" value="<?php echo ( isset( $uploaded_to_this_item ) ? esc_html( $uploaded_to_this_item ) : '' ); ?>" required>
                                        <span class="highlight"></span>
                                        <span class="bar"></span>
                                        <label><?php _e( 'Uploaded To This Item', 'easy-custom-post-type-ui' ); ?></label>
                                        <p><?php _e( 'Uploaded To This Item Label For Your Custom Post Type.', 'easy-custom-post-type-ui' ); ?></p>
                                    </div>

                                    <div class="post-input-group">
                                        <input type="text" name="_filter_items_list" value="<?php echo ( isset( $filter_items_list ) ? esc_html( $filter_items_list ) : '' ); ?>" required>
                                        <span class="highlight"></span>
                                        <span class="bar"></span>
                                        <label><?php _e( 'Filter Items List', 'easy-custom-post-type-ui' ); ?></label>
                                        <p><?php _e( 'Filter Items List Label For Your Custom Post Type.', 'easy-custom-post-type-ui' ); ?></p>
                                    </div>

                                    <div class="post-input-group">
                                        <input type="text" name="_items_list_navigation" value="<?php echo ( isset( $items_list_navigation ) ? esc_html( $items_list_navigation ) : '' ); ?>" required>
                                        <span class="highlight"></span>
                                        <span class="bar"></span>
                                        <label><?php _e( 'Items List Navigation', 'easy-custom-post-type-ui' ); ?></label>
                                        <p><?php _e( 'Items List Navigation Label For Your Custom Post Type.', 'easy-custom-post-type-ui' ); ?></p>
                                    </div>

                                    <div class="post-input-group">
                                        <input type="text" name="_items_list" value="<?php echo ( isset( $items_list ) ? esc_html( $items_list ) : '' ); ?>" required>
                                        <span class="highlight"></span>
                                        <span class="bar"></span>
                                        <label><?php _e( 'Items List', 'easy-custom-post-type-ui' ); ?></label>
                                        <p><?php _e( 'Items List Label For Your Custom Post Type.', 'easy-custom-post-type-ui' ); ?></p>
                                    </div>
                                </div>
                            </div>
                        </details>
                        <!-- Main Labels End -->

                        <!-- Main Args Start -->
                        <details class="post-section-item">
                            <summary class="post-section-question"><?php _e( 'Args Settings', 'easy-custom-post-type-ui' ); ?><span class="post-section-icon"></span></summary>
                            <div class="post-section-answer">
                                <div class="post-section-answer-inner">
                                    <div class="post-args-container">
                                        <div class="post-args-row">
                                            <label class="post-args-label" for="public"><?php _e( 'Public', 'easy-custom-post-type-ui' ); ?></label>
                                            <div class="post-options" id="options">
                                                <select class="hide-option option" id="hide-option" name="_public_args">
                                                    <option value="true"    <?php echo ( isset( $public_args ) && "true"  === esc_attr( $public_args ) ? 'selected' : '' );  ?> ><?php _e('True', 'easy-custom-post-type-ui'); ?></option>
                                                    <option value="false"   <?php echo ( isset( $public_args ) && "false" === esc_attr( $public_args ) ? 'selected' : '' );  ?> ><?php _e('False', 'easy-custom-post-type-ui'); ?></option>
                                                </select>
                                                <p><?php _e( '(Custom Post Type UI default: true) Whether or not posts of this type should be shown in the admin UI and is publicly queryable.', 'easy-custom-post-type-ui' ); ?></p>
                                            </div>
                                        </div>

                                        <div class="post-args-row">
                                            <label class="post-args-label" for="public"><?php _e( 'Publicly Queryable', 'easy-custom-post-type-ui' ); ?></label>
                                            <div class="post-options" id="options">
                                                <select class="hide-option option" id="hide-option" name="_publicly_queryable">
                                                    <option value="true"    <?php echo ( isset( $publicly_queryable ) && "true"   === esc_attr( $publicly_queryable ) ? 'selected' : '' );  ?> ><?php _e('True', 'easy-custom-post-type-ui'); ?></option>
                                                    <option value="false"   <?php echo ( isset( $publicly_queryable ) && "false"  === esc_attr( $publicly_queryable ) ? 'selected' : '' );  ?> ><?php _e('False', 'easy-custom-post-type-ui'); ?></option>
                                                </select>
                                                <p><?php _e(' (default: true) Whether or not queries can be performed on the front end as part of parse_request()', 'easy-custom-post-type-ui' ); ?></p>
                                            </div>
                                        </div>

                                        <div class="post-args-row">
                                            <label class="post-args-label" for="public"><?php _e('Show Ui', 'easy-custom-post-type-ui'); ?></label>
                                            <div class="post-options" id="options">
                                                <select class="hide-option option" id="hide-option" name="_show_ui">
                                                    <option value="true"    <?php echo ( isset( $show_ui ) && "true"   === esc_attr( $show_ui ) ? 'selected' : '' );  ?> ><?php _e('True', 'easy-custom-post-type-ui'); ?></option>
                                                    <option value="false"   <?php echo ( isset( $show_ui ) && "false"  === esc_attr( $show_ui ) ? 'selected' : '' ); ?> ><?php _e('False', 'easy-custom-post-type-ui'); ?></option>
                                                </select>
                                                <p><?php _e( '(default: true) Whether or not to generate a default UI for managing this post type.', 'easy-custom-post-type-ui' ); ?></p>
                                            </div>
                                        </div>

                                        <div class="post-args-row">
                                            <label class="post-args-label" for="public"><?php _e( 'Show Ui', 'easy-custom-post-type-ui' ); ?></label>
                                            <div class="post-options" id="options">
                                                <select class="hide-option option" id="hide-option" name="_show_in_menu">
                                                    <option value="true"    <?php echo ( isset( $show_in_menu ) && "true"   === esc_attr( $show_in_menu ) ? 'selected' : '' );  ?> ><?php _e('True', 'easy-custom-post-type-ui'); ?></option>
                                                    <option value="false"   <?php echo ( isset( $show_in_menu ) && "false"  === esc_attr( $show_in_menu ) ? 'selected' : '' );  ?> ><?php _e('False', 'easy-custom-post-type-ui'); ?></option>
                                                </select>
                                                <p><?php _e( '(default: true) Whether or not to generate a default UI for managing this post type.', 'easy-custom-post-type-ui' ); ?></p>
                                            </div>
                                        </div>

                                        <div class="post-args-row">
                                            <label class="post-args-label" for="public"><?php _e( 'Query Var', 'easy-custom-post-type-ui' ); ?></label>
                                            <div class="post-options" id="options">
                                                <select class="hide-option option" id="hide-option" name="_query_var">
                                                    <option value="true"  <?php echo ( isset( $query_var ) && "true"  === esc_attr( $query_var ) ? 'selected' : '' );  ?> ><?php _e('True', 'easy-custom-post-type-ui'); ?></option>
                                                    <option value="false" <?php echo ( isset( $query_var ) && "false" === esc_attr( $query_var ) ? 'selected' : '' );  ?> ><?php _e('False', 'easy-custom-post-type-ui'); ?></option>
                                                </select>
                                                <p><?php _e( '(default: true) Sets the query_var key for this post type.', 'easy-custom-post-type-ui' ); ?></p>
                                            </div>
                                        </div>

                                        <div class="post-args-row">
                                            <label class="post-args-label" for="public"><?php _e( 'Rewrite', 'easy-custom-post-type-ui' ); ?></label>
                                            <div class="post-options" id="options">
                                                <select class="hide-option option" id="hide-option" name="_rewrite">
                                                    <option value="true"  <?php echo ( isset( $rewrite ) && "true"  === esc_attr( $rewrite ) ? 'selected' : '' );  ?> ><?php _e('True', 'easy-custom-post-type-ui'); ?></option>
                                                    <option value="false" <?php echo ( isset( $rewrite ) && "false" === esc_attr( $rewrite ) ? 'selected' : '' );  ?> ><?php _e('False', 'easy-custom-post-type-ui'); ?></option>
                                                </select>
                                                <p><?php _e( '(default: true) Whether or not WordPress should use rewrites for this post type.', 'easy-custom-post-type-ui' ); ?></p>
                                            </div>
                                        </div>

                                        <div class="post-args-row">
                                            <label class="post-args-label" for="public"><?php _e( 'Has Archive', 'easy-custom-post-type-ui' ); ?></label>
                                            <div class="post-options" id="options">
                                                <select class="hide-option option" id="hide-option" name="_has_archive">
                                                    <option value="true"    <?php echo ( isset( $has_archive ) && "true"  === esc_attr( $has_archive ) ? 'selected' : '' );  ?> ><?php _e('True', 'easy-custom-post-type-ui'); ?></option>
                                                    <option value="false"   <?php echo ( isset( $has_archive ) && "false" === esc_attr( $has_archive ) ? 'selected' : '' ); ?> ><?php _e('False', 'easy-custom-post-type-ui'); ?></option>
                                                </select>
                                                <p><?php _e( '(default: false) Whether or not the post type will have a post type archive URL.', 'easy-custom-post-type-ui' ); ?></p>
                                            </div>
                                        </div>

                                        <div class="post-args-row">
                                            <label class="post-args-label" for="public"><?php _e( 'Hierarchical', 'easy-custom-post-type-ui' ); ?></label>
                                            <div class="post-options" id="options">
                                                <select class="hide-option option" id="hide-option" name="_hierarchical">
                                                    <option value="true"    <?php echo ( isset( $hierarchical ) && "true" === esc_attr( $hierarchical ) ? 'selected' : '' ); ?> ><?php _e('True', 'easy-custom-post-type-ui'); ?></option>
                                                    <option value="false"   <?php echo ( isset( $hierarchical ) && "false" === esc_attr( $hierarchical ) ? 'selected' : '' ); ?> ><?php _e('False', 'easy-custom-post-type-ui'); ?></option>
                                                </select>
                                                <p><?php _e( '(default: false) Whether or not the post type can have parent-child relationships. At least one published content item is needed in order to select a parent.', 'easy-custom-post-type-ui' ); ?></p>
                                            </div>
                                        </div>

                                        <div class="post-args-row">
                                            <label class="post-args-label" for="public"><?php _e( 'Menu Position', 'easy-custom-post-type-ui' ); ?></label>
                                            <div class="post-input-group post-options">
                                                <input type="text" name="_menu_position" value="<?php echo ( isset( $menu_position ) ? esc_html( $menu_position ) : '' ); ?>" required>
                                                <span class="highlight"></span>
                                                <span class="bar"></span>
                                                <label><?php _e( 'Post Menu Position', 'easy-custom-post-type-ui' ); ?></label>
                                                <p><?php _e( 'The position in the menu order the post type should appear. show_in_menu must be true.', 'easy-custom-post-type-ui' ); ?></p>
                                                <strong><?php _e( 'See', 'easy-custom-post-type-ui' ); ?><a href="https://developer.wordpress.org/reference/functions/register_post_type/#menu_position"><?php _e( 'Available Options', 'easy-custom-post-type-ui' ); ?></a><?php _e( 'in The Menu Position Section. Range of 5-100', 'easy-custom-post-type-ui' ); ?></strong>
                                            </div>
                                        </div>

                                        <div class="post-args-row">
                                            <label class="post-args-label" for="public"><?php _e( 'Menu Icon', 'easy-custom-post-type-ui' ); ?></label>
                                            <div class="post-input-group post-options">
                                                <span class="current-dashicons dashicons <?php echo esc_attr( $dash_icons ); ?>"></span>
                                                <input class="regular-text dashicons_picker_example_icon1 icons" name="_dash_icons" type="hidden" value="<?php echo esc_attr( $dash_icons ); ?>"/>
                                                <input class="button dashicons-picker" type="button" value="Choose Icon" data-target=".dashicons_picker_example_icon1" />
                                            </div>
                                        </div>
                                    </div>
                                </div>
                            </div>
                        </details>
                        <!-- Main Args End -->

                        <!-- Main Supports Start -->
                        <details class="post-section-item">
                            <summary class="post-section-question"><?php _e( 'Supports Settings', 'easy-custom-post-type-ui' ); ?><span class="post-section-icon"></span></summary>
                            <div class="post-section-answer">
                                <div class="post-section-answer-inner">
                                    <div class="post-args-container">
                                        
                                        <!-- Post Supports Title -->
                                        <table>
                                            <tbody>
                                                <tr>
                                                    <td>
                                                        <label for=""><?php _e( 'Title', 'easy-custom-post-type-ui' ); ?></label>
                                                    </td>
                                                    <td>
                                                        <label>
                                                            <input type="checkbox" class="post-supports-switch" name="_post_supports_title"  value="yes" <?php echo ( isset( $supports_title ) && ( 'yes' == esc_attr( $supports_title ) ) ) ? ' checked="checked"' : ''; ?> >
                                                            <span class="toggle_background">
                                                                <div class="circle-icon"></div>
                                                                <div class="vertical_line"></div>
                                                            </span>
                                                        </label>
                                                    </td>
                                                </tr>

                                                <tr>
                                                <td>
                                                        <label for=""><?php _e( 'Editor', 'easy-custom-post-type-ui' ); ?></label>
                                                </td>
                                                    <td>
                                                        <label>
                                                            <input type="checkbox" class="post-supports-switch" name="_post_supports_editor"  value="yes" <?php echo ( isset( $supports_editor ) && ( 'yes' == esc_attr( $supports_editor ) ) ) ? ' checked="checked"' : ''; ?> >
                                                            <span class="toggle_background">
                                                                <div class="circle-icon"></div>
                                                                <div class="vertical_line"></div>
                                                            </span>
                                                        </label>
                                                    </td>
                                                </tr>

                                                <tr>
                                                    <td>
                                                        <label for=""><?php _e( 'Author', 'easy-custom-post-type-ui' ); ?></label>
                                                    </td>
                                                    <td>
                                                        <label>
                                                            <input type="checkbox" class="post-supports-switch" name="_post_supports_author"  value="yes" <?php echo ( isset( $supports_author ) && ( 'yes' == esc_attr( $supports_author ) ) ) ? ' checked="checked"' : ''; ?> >
                                                            <span class="toggle_background">
                                                                <div class="circle-icon"></div>
                                                                <div class="vertical_line"></div>
                                                            </span>
                                                        </label>
                                                    </td>
                                                </tr>

                                                <tr>
                                                    <td>
                                                        <label for=""><?php _e( 'Thumbnail', 'easy-custom-post-type-ui' ); ?></label>
                                                    </td>
                                                    <td>
                                                        <label>
                                                            <input type="checkbox" class="post-supports-switch" name="_post_supports_thumbnail"  value="yes" <?php echo ( isset( $supports_thumbnail ) && ( 'yes' == esc_attr( $supports_thumbnail ) ) ) ? ' checked="checked"' : ''; ?> >
                                                            <span class="toggle_background">
                                                                <div class="circle-icon"></div>
                                                                <div class="vertical_line"></div>
                                                            </span>
                                                        </label>
                                                    </td>
                                                </tr>

                                                <tr>
                                                    <td>
                                                        <label for=""><?php _e( 'Excerpt', 'easy-custom-post-type-ui' ); ?></label>
                                                    </td>
                                                    <td>
                                                        <label>
                                                            <input type="checkbox" class="post-supports-switch" name="_post_supports_excerpt"  value="yes" <?php echo ( isset( $supports_excerpt ) && ( 'yes' == esc_attr( $supports_excerpt ) ) ) ? ' checked="checked"' : ''; ?> >
                                                            <span class="toggle_background">
                                                                <div class="circle-icon"></div>
                                                                <div class="vertical_line"></div>
                                                            </span>
                                                        </label>
                                                    </td>
                                                </tr>

                                                <tr>
                                                    <td>
                                                        <label for=""><?php _e( 'Comments', 'easy-custom-post-type-ui' ); ?></label>
                                                    </td>
                                                    <td>
                                                        <label>
                                                            <input type="checkbox" class="post-supports-switch" name="_post_supports_comments"  value="yes" <?php echo ( isset( $supports_comments ) && ( 'yes' == esc_attr( $supports_comments ) ) ) ? ' checked="checked"' : ''; ?> >
                                                            <span class="toggle_background">
                                                                <div class="circle-icon"></div>
                                                                <div class="vertical_line"></div>
                                                            </span>
                                                        </label>
                                                    </td>
                                                </tr>
                                            </tbody>
                                        </table>
                                    </div>
                                </div>
                            </div>
                        </details>
                        <!-- Main Supports End -->
                    </div>
                </section>

                <div class="submit-btn-section">
                    <button class="custom-btn btn-12"><span><?php _e( 'Click!', 'easy-custom-post-type-ui' ); ?></span><span><?php _e( 'Submit', 'easy-custom-post-type-ui' ); ?></span></button>
                </div>
            </div>
        </div>
    </main>
</div>