<?php

/**
 * The plugin bootstrap file
 *
 * This file is read by WordPress to generate the plugin information in the plugin
 * admin area. This file also includes all of the dependencies used by the plugin,
 * registers the activation and deactivation functions, and defines a function
 * that starts the plugin.
 *
 * @link              https://hashtechy.com
 * @since             1.0.0
 * @package           Easy_Custom_Post_Type_Ui
 *
 * @wordpress-plugin
 * Plugin Name:       Easy Custom Post Type UI
 * Plugin URI:        https://hashtechy.com
 * Description:       Easy Custom Post Type UI offers a simple-to-use interface for creating and maintaining taxonomies and custom post types for your website.
 * Version:           1.0.0
 * Author:            Hashtechy
 * Author URI:        https://hashtechy.com
 * License:           GPL-2.0+
 * License URI:       http://www.gnu.org/licenses/gpl-2.0.txt
 * Text Domain:       easy-custom-post-type-ui
 * Domain Path:       /languages
 */

// If this file is called directly, abort.
if ( ! defined( 'WPINC' ) ) {
	die;
}

/**
 * Currently plugin version.
 * Start at version 1.0.0 and use SemVer - https://semver.org
 * Rename this for your plugin and update it as you release new versions.
 */
define( 'EASY_CUSTOM_POST_TYPE_UI_VERSION', '1.0.0' );

/**
 * The code that runs during plugin activation.
 * This action is documented in includes/class-easy-custom-post-type-ui-activator.php
 */
function activate_easy_custom_post_type_ui() {
	require_once plugin_dir_path( __FILE__ ) . 'includes/class-easy-custom-post-type-ui-activator.php';
	Easy_Custom_Post_Type_Ui_Activator::activate();
}

/**
 * The code that runs during plugin deactivation.
 * This action is documented in includes/class-easy-custom-post-type-ui-deactivator.php
 */
function deactivate_easy_custom_post_type_ui() {
	require_once plugin_dir_path( __FILE__ ) . 'includes/class-easy-custom-post-type-ui-deactivator.php';
	Easy_Custom_Post_Type_Ui_Deactivator::deactivate();
}

register_activation_hook( __FILE__, 'activate_easy_custom_post_type_ui' );
register_deactivation_hook( __FILE__, 'deactivate_easy_custom_post_type_ui' );

/**
 * The core plugin class that is used to define internationalization,
 * admin-specific hooks, and public-facing site hooks.
 */
require plugin_dir_path( __FILE__ ) . 'includes/class-easy-custom-post-type-ui.php';

/**
 * Begins execution of the plugin.
 *
 * Since everything within the plugin is registered via hooks,
 * then kicking off the plugin from this point in the file does
 * not affect the page life cycle.
 *
 * @since    1.0.0
 */
function run_easy_custom_post_type_ui() {

	$plugin = new Easy_Custom_Post_Type_Ui();
	$plugin->run();

}
run_easy_custom_post_type_ui();
